@@ -3,12 +3,12 @@ import json
 
 
 __FILE_DIR = os.path.dirname(__file__)
-__FORMAT_CONFIG = os.path.join(__FILE_DIR, 'config.json')
+__FORMAT_CONFIG = os.path.join(__FILE_DIR, "config.json")
 
 
 CONFIG = {}
-ITERATION_KEY = 'iteration_formats'
-COMPRESSED_FILEPATH_TYPES_KEY = 'compressed_filepath_types'
+ITERATION_KEY = "iteration_formats"
+COMPRESSED_FILEPATH_TYPES_KEY = "compressed_filepath_types"
 
 
 if os.path.exists(__FORMAT_CONFIG):
